<?php
class Games extends Application
{

	public $db;

	public function __construct()	{
		//fetch db from Application for reference
		$this->db = parent::getDatabase();
	}

	public function getGames($data = array(), $onlycount = 0) {
		if ($onlycount != 1) {
			$sql = "SELECT g.*, u.user_first as creator_first, u.user_last as creator_last, gt.type_name as type_name, gt.type_constant FROM `games` g ";
			$sql .= "LEFT JOIN `games_types` gt ON g.type = gt.id ";
			$sql .= "LEFT JOIN `user` u ON u.user_id = g.created_user_id ";
		} else {
			$sql = "SELECT COUNT(g.id) FROM `games` g ";
		}

		$sql .= " WHERE g.id != '' AND active = 1";

		$pdo_variables = array();

		if (!empty($data['filter_id'])) {
			if (!empty(str_replace(" ","",$data['filter_id']))) {
				$explode = explode (" ", $data['filter_id']);
				$sql .= " AND (";
				$count = 0;
				foreach ($explode as $val) {
					if ($count > 0) {
						$sql .= " OR ";
					}
					$sql .= "g.id = ?";
					$pdo_variables[] = $val;
					$count++;
				}
				$sql .= ")";
			}
		}

		if (!empty($data['exclude_id'])) {
			if (!empty(str_replace(" ","",$data['exclude_id']))) {
				$explode = explode (" ", $data['exclude_id']);
				foreach ($explode as $val) {
					if (!empty($val)) {
						$sql .= " AND NOT g.id = ?";
						$pdo_variables[] = $val;
					}
				}
			}
		}

		if (!empty($data['filter_user'])) {
			if (!empty(str_replace(" ","",$data['filter_user']))) {
				$explode = explode (" ", $data['filter_user']);
				$sql .= " AND (";
				$count = 0;
				foreach ($explode as $val) {
					if ($count > 0) {
						$sql .= " OR ";
					}
					$sql .= "g.created_user_id = ?";
					$pdo_variables[] = $val;
					$count++;
				}
				$sql .= ")";
			}
		}

		if (!empty($data['filter_type'])) {
			if (!empty(str_replace(" ","",$data['filter_type']))) {
				$explode = explode (" ", $data['filter_type']);
				$sql .= " AND (";
				$count = 0;
				foreach ($explode as $val) {
					if ($count > 0) {
						$sql .= " OR ";
					}
					$sql .= "g.type = ?";
					$pdo_variables[] = $val;
					$count++;
				}
				$sql .= ")";
			}
		}

		if (!empty($data['filter_name'])) {
			if (!empty(str_replace(" ","",$data['filter_name']))) {
				$explode = explode (" ", $data['filter_name']);
				$sql .= " AND (";
				$count = 0;
				foreach ($explode as $val) {
					if ($count > 0) {
						$sql .= " OR ";
					}
					$sql .= "g.name LIKE ?";
					$pdo_variables[] = "%".$val."%";
					$count++;
				}
				$sql .= ")";
			}
		}

		if (!empty($data['filter_difficulty'])) {
			if (!empty(str_replace(" ","",$data['filter_difficulty']))) {
				$explode = explode (" ", $data['filter_difficulty']);
				$sql .= " AND (";
				$count = 0;
				foreach ($explode as $val) {
					if ($count > 0) {
						$sql .= " OR ";
					}
					$sql .= "g.difficulty LIKE ?";
					$pdo_variables[] = "%".$val."%";
					$count++;
				}
				$sql .= ")";
			}
		}

		if (!empty($data['sort'])) {
			$sql .= " ORDER BY " . $data['sort'];

			if (isset($data['order']) && ($data['order'] == 'ASC')) {
				$sql .= " ASC ";
			} else {
				$sql .= " DESC, g.id DESC";
			}
		} else {
			$sql .= " ORDER BY g.type ASC, g.difficulty ASC ";
		}

		if (isset($data['start']) || isset($data['limit'])) {
			if (empty($data['start'])) {
				$data['start'] = 0;
			}
			if (empty($data['limit'])) {
				$data['limit'] = 20;
			}
			$sql .= " LIMIT ".$data['start']." , ".$data['limit']." ";
		}

		$query = $this->db->prepare($sql);

		$query->execute($pdo_variables);

		/*$logger = new Logger();
		echo "<p>".$logger->fillSQLsequential($sql, $pdo_variables)."</p>";*/

		if ($onlycount != 1) {
			$data = $query->fetchAll(PDO::FETCH_OBJ);
		} else {
			$data = $query->fetchColumn();
		}
		return $data;
	}

	public function getGame($id) {
		$query = $this->db->prepare("SELECT * FROM `games` WHERE `id`= :id");
		$query->execute(array(':id' => $id));
		$resource = $query->fetch(PDO::FETCH_OBJ);
		return $resource;
	}

	public function getCompleteGame($id) {
		$query = $this->db->prepare("SELECT * FROM `games` WHERE `id`= :id");
		$query->execute(array(':id' => $id));
		$resource = $query->fetch(PDO::FETCH_OBJ);
		return $resource;
	}

	public function getResourceTypes() {
		$query = $this->db->prepare("SELECT * FROM `resources_types` WHERE active = 1");
		$query->execute();
		$data = $query->fetchAll(PDO::FETCH_OBJ);

		return $data;
	}


	public function addTagRow($id) {
		$return = "";

		$sql = "SELECT t.*, tj.resource_count FROM tags t LEFT JOIN (SELECT COUNT(id) as resource_count, tag_id FROM resource_to_tags WHERE tag_id = :id GROUP BY tag_id) tj ON tj.tag_id = t.id WHERE t.id=:id";
		$query = $this->db->prepare($sql);
		$query->execute(array('id'=>$id));
		$tag = $query->fetch();

		if (!empty($tag['id'])) {
			$return  = 	'<tr class="tag_row" id="tag_row_'.$tag['id'].'" tags_id="'.$tag['id'].'">';
			$return .= 		'<input type="hidden" name="tags[]" value="'.$tag['id'].'">';
			$return .= 		'<td>'.$tag['id'].'</td>';
			$return .= 		'<td>'.$tag['tag'].'</td>';
			$return .= 		'<td>'.$tag['resource_count'].'</td>';
			$return .= 		'<td><a href="#" onclick="removeTagRow('.$tag['id'].');return false;"><i class="fas fa-times"></i></a>';
			$return .= 	'</tr>';
		}

		return $return;
	}

	public function fillTagRows($games_id) {
		$query = $this->db->prepare("SELECT * FROM `game_to_tags` WHERE game_id = :games_id");
		$pdo_array = array();
		$pdo_array[':games_id'] = $games_id;
		$query->execute($pdo_array);
		$data = $query->fetchAll(PDO::FETCH_OBJ);

		$return = "";

		foreach ($data as $tag) {
			$return .= $this->addTagRow($tag->tag_id);
		}

		return $return;
	}

	public function filterTagSelect($filter_name, $exclude_id) {
		$return = "";

		$sql = "SELECT t.*, tj.resource_count FROM tags t LEFT JOIN (SELECT COUNT(id) as resource_count, tag_id FROM resource_to_tags GROUP BY tag_id) tj ON tj.tag_id = t.id ";
		$sql .= "WHERE t.id IS NOT NULL AND t.active = 1 ";

		$pdo_variables = array();

		if (!empty($exclude_id)) {
			if (!empty(str_replace(" ","", $exclude_id))) {
				$explode = explode (" ", $exclude_id);
				foreach ($explode as $val) {
					if (!empty($val)) {
						$sql .= " AND NOT t.id = ?";
						$pdo_variables[] = $val;
					}
				}
			}
		}

		if (!empty($filter_name)) {
			if (!empty(str_replace(" ","", $filter_name))) {
				$explode = explode (" ", $filter_name);
				$sql .= " AND (";
				$count = 0;
				foreach ($explode as $val) {
					if ($count > 0) {
						$sql .= " OR ";
					}
					$sql .= "t.tag LIKE ?";
					$pdo_variables[] = "%".$val."%";
					$count++;
				}
				$sql .= ")";
			}
		}

		$sql .= "ORDER BY tag ASC LIMIT 2000";

		//$logger = new Logger();
		//echo "<p>".$logger->fillSQLsequential($sql, $pdo_variables)."</p>";

		$query = $this->db->prepare($sql);
		$query->execute($pdo_variables);
		$data = $query->fetchAll(PDO::FETCH_OBJ);

		$return .= '<select id="searchTag" name="searchTag">';
		$return .= '<option value="" selected></option>';
		foreach($data as $tag) {
			if (empty($tag->resource_count)) {$tag->resource_count = 0;}
			//if ($tag->resource_count == 0) continue;

			$return .= '<option value="'.$tag->id.'">'.$tag->tag.' ('.$tag->resource_count.') ID: '.$tag->id.'</option>';
		}
		$return .= '</select>';

		return $return;
	}

	public function addGame($data = array()) {
    	if(!empty($data)) {
	    	$sql = "INSERT INTO `games`(";
			$fields = array();

			//list of fields in the table
			$clearing_fields = array(
				'type',
				'name',
				'note',
				'display_count',
				'display_resource_type',
				'response_resource_type',
				'difficulty'
			);

			$fields['created'] = date("Y-m-d H:i:s");
			$fields['updated'] = date("Y-m-d H:i:s");
			$fields['created_user_id'] = $this->getGlobalUser();
			$fields['updated_user_id'] = $this->getGlobalUser();

			foreach($clearing_fields as $field) {
				if(isset($data[$field])) {
					if($data[$field] == '') {
						$fields[$field] = NULL;
					} else {
						$fields[$field] = $data[$field];
					}
				}
			}

			//map the fields to the right area of sql query
			foreach($fields as $field_name=>$value) {
				$names[] = $field_name;
				$values[] = $value;
			}

			//build the columns list to update
			$i = 0;
			$len = count($names);
			foreach($names as $name) {
				$sql .= '`'.$name.'`';
				if ($i != $len - 1) {
			        $sql .= ", ";
			    } else {
			    	$sql .= ") VALUES (";
				}
				$i++;
			}

			//build the values list to update
			$i = 0;
			$len = count($values);
			foreach($names as $name) {
				$sql .= ":". $name;
				if ($i != $len - 1) {
			        $sql .= ", ";
			    } else {
			    	$sql .= ")";
				}
				$i++;
			}

			//set up all the pdo prepare statements
			$pdo_array = array();
			foreach($fields as $field_name=>$value) {
				$pdo_array[':'.$field_name] = $value;
			}

			//prepare the query
			$query = $this->db->prepare($sql);

			//execute query with all variables
			$query->execute($pdo_array);

			$id = $this->db->lastInsertId();

			$logger = new Logger();
			$logger->logPDO("".$this->getGlobalUser(), "games", "add new", $id, $sql, $pdo_array);
		}
		return $id;
	}

	public function updateGame($data = array()) {
    	if(!empty($data)) {
	    	$sql = "UPDATE `games` SET";
			$fields = array();

			//list of fields in the table
			$table_fields = array(
				'type',
				'name',
				'note',
				'display_count',
				'display_resource_type',
				'response_resource_type',
				'difficulty'
			);

			$fields['updated'] = date("Y-m-d H:i:s");
			$fields['updated_user_id'] = $this->getGlobalUser();

			foreach($table_fields as $field) {
				if(isset($data[$field])) {
					if($data[$field] == '') {
						$fields[$field] = NULL;
					} else {
						$fields[$field] = $data[$field];
					}
				}
			}

			//map the fields to the right area of sql query
			foreach($fields as $field_name=>$value) {
				$sql .= ' `' . $field_name . '`=:' . $field_name .',';
			}

			//set up all the pdo prepare statements
			$pdo_array = array();
			foreach($fields as $field_name=>$value) {
				$pdo_array[':'.$field_name] = $value;
			}

			//strip comman from last entry
			$sql = rtrim($sql, ",");

			$sql .= " WHERE `id`= :id";
			$pdo_array[':id'] = $data['id'];

			//prepare the query
			$query = $this->db->prepare($sql);

			//execute query with all variables
			$query->execute($pdo_array);

			$logger = new Logger();
			$logger->logPDO("".$this->getGlobalUser(), "games", "update", $data['id'], $sql, $pdo_array);
		}
		return;
	}

	public function setTags($id, $tag_array) {
		$sql = "DELETE FROM game_to_tags WHERE game_id = :id";
		$result = $this->db->prepare($sql);
		$pdo_array[':id']  = $id;
		$result->execute($pdo_array);

		$logger = new Logger();
		$log_sql = "";
		$log_count = 0;
		$batch_count = 0;

		if(count( $tag_array) > 0) {
			foreach ( $tag_array as $tag ) {
				if ( $log_count > 50 ) {
					$batch_count ++;
					$logger->log( "" . $this->getGlobalUser(), "game_to_tags", "set tags - batch " . $batch_count, $id, $log_sql );
					$log_sql   = "";
					$log_count = 0;
				}

				$sql                  = "INSERT INTO game_to_tags (game_id, tag_id) VALUES (:id, :tag_id)";
				$pdo_array[':tag_id'] = $tag;
				$result               = $this->db->prepare( $sql );
				$result->execute( $pdo_array );

				$log_sql .= $logger->fillSQL( $sql, $pdo_array ) . "\n";
				$log_count ++;
			}
		}

		$logger->log("".$this->getGlobalUser(), "game_to_tags", "set tags", $id, $log_sql);
	}

	public function delete($id) {
		$sql = "UPDATE `games` SET active = 0 WHERE id = :id";
		$result = $this->db->prepare($sql);
		$pdo_array[':id']  = $id;
		$result->execute($pdo_array);

		$logger = new Logger();
		$logger->logPDO("".$this->getGlobalUser(), "games", "delete", $id, $sql, $pdo_array);

		return true;;
	}

	public function getGameTypeName($id) {
		$query = $this->db->prepare("SELECT type_name FROM `games_types` WHERE `id`= :id");
		$query->execute(array(':id' => $id));
		$resource = $query->fetch(PDO::FETCH_OBJ);
		return $resource->type_name;
	}

	public function getTags($game_id) {
		$query = $this->db->prepare("SELECT tag_id FROM `game_to_tags` WHERE `game_id`= :id");
		$query->execute(array(':id' => $game_id));
		$tags = $query->fetchAll(PDO::FETCH_OBJ);
		return $tags;
	}

	public function getResources($game_id, $display_count = 2000) {
		$tags = $this->getTags($game_id);
		$count = 0;
		$resources = array();
		foreach($tags as $tag) {
			$query = $this->db->prepare("SELECT DISTINCT r.id, r.* FROM resources r LEFT JOIN resource_to_tags rtt ON r.id = rtt.resource_id WHERE rtt.tag_id= :id");
			$query->execute(array(':id' => $tag->tag_id));
			$resource = $query->fetchAll(PDO::FETCH_OBJ);
			foreach($resource as &$res) {

    			$query = $this->db->prepare("SELECT * FROM resources_files WHERE resources_files.resources_id= :id");
    			$query->execute(array(':id' => $res->id));
    			$files = $query->fetchAll(PDO::FETCH_OBJ);

    			$res->files = $files;

				$resources[] = $res;
			}
		}
		shuffle($resources);
		$resources = array_slice($resources,0,$display_count);
		return $resources;
	}































	public function getCount() {
		$sql = "SELECT count(*) FROM `resources` WHERE active = 1";
		$result = $this->db->prepare($sql);
		$result->execute();
		$number_of_rows = $result->fetchColumn();
		return $number_of_rows;
	}





	public function addResource($data = array()) {
    	if(!empty($data)) {
	    	$sql = "INSERT INTO `resources`(";
			$fields = array();

			//list of fields in the table
			$clearing_fields = array(
				'swe_word',
				'elfdalian_word'
			);

			$fields['created'] = date("Y-m-d H:i:s");
			$fields['updated'] = date("Y-m-d H:i:s");
			$fields['created_user_id'] = $this->getGlobalUser();
			$fields['updated_user_id'] = $this->getGlobalUser();

			foreach($clearing_fields as $field) {
				if(isset($data[$field])) {
					if($data[$field] == '') {
						$fields[$field] = NULL;
					} else {
						$fields[$field] = $data[$field];
					}
				}
			}

			//map the fields to the right area of sql query
			foreach($fields as $field_name=>$value) {
				$names[] = $field_name;
				$values[] = $value;
			}

			//build the columns list to update
			$i = 0;
			$len = count($names);
			foreach($names as $name) {
				$sql .= '`'.$name.'`';
				if ($i != $len - 1) {
			        $sql .= ", ";
			    } else {
			    	$sql .= ") VALUES (";
				}
				$i++;
			}

			//build the values list to update
			$i = 0;
			$len = count($values);
			foreach($names as $name) {
				$sql .= ":". $name;
				if ($i != $len - 1) {
			        $sql .= ", ";
			    } else {
			    	$sql .= ")";
				}
				$i++;
			}

			//set up all the pdo prepare statements
			$pdo_array = array();
			foreach($fields as $field_name=>$value) {
				$pdo_array[':'.$field_name] = $value;
			}

			//prepare the query
			$query = $this->db->prepare($sql);

			//execute query with all variables
			$query->execute($pdo_array);

			$id = $this->db->lastInsertId();

			$logger = new Logger();
			$logger->logPDO("".$this->getGlobalUser(), "resources", "add new", $id, $sql, $pdo_array);
		}
		return $id;
	}

	public function updateResource($data = array()) {
    	if(!empty($data)) {
	    	$sql = "UPDATE `resources` SET";
			$fields = array();

			//list of fields in the table
			$table_fields = array(
				'swe_word',
				'elfdalian_word'
			);

			$fields['updated'] = date("Y-m-d H:i:s");
			$fields['updated_user_id'] = $this->getGlobalUser();

			foreach($table_fields as $field) {
				if(isset($data[$field])) {
					if($data[$field] == '') {
						$fields[$field] = NULL;
					} else {
						$fields[$field] = $data[$field];
					}
				}
			}

			//map the fields to the right area of sql query
			foreach($fields as $field_name=>$value) {
				$sql .= ' `' . $field_name . '`=:' . $field_name .',';
			}

			//set up all the pdo prepare statements
			$pdo_array = array();
			foreach($fields as $field_name=>$value) {
				$pdo_array[':'.$field_name] = $value;
			}

			//strip comman from last entry
			$sql = rtrim($sql, ",");

			$sql .= " WHERE `id`= :id";
			$pdo_array[':id'] = $data['id'];

			//prepare the query
			$query = $this->db->prepare($sql);

			//execute query with all variables
			$query->execute($pdo_array);

			$logger = new Logger();
			$logger->logPDO("".$this->getGlobalUser(), "resources", "update", $data['id'], $sql, $pdo_array);
		}
		return;
	}

	public function addResourceFile($resources_id, $file, $file_type) {
		$_FILES["fileToUpload"] = $file;
		if (!empty($_FILES["fileToUpload"]["name"])) {
			$existing_count_q = "SELECT count(id) FROM `resources_files` WHERE resources_id = :resources_id AND type = :type";
			$pdo_array[':type'] = $file_type;
			$pdo_array[':resources_id'] = $resources_id;
			$result = $this->db->prepare($existing_count_q);
			$result->execute($pdo_array);
			$number_of_rows = $result->fetchColumn();

			$explode = explode (".", $_FILES["fileToUpload"]["name"]);
			if (count($explode) > 1) {
				$suffix = ".".$explode[count($explode)-1];

				$_FILES["fileToUpload"]["name"] = $resources_id."_".$file_type."_".$number_of_rows.$suffix;
				$data = array();
				$data['target'] = "resourcefiles/".urlencode($file_type)."/";

				$file_return = $this->uploadFile($_FILES, $this->getGlobalUser(), $data);
				$file_success = $file_return['status'];
				if($file_success == 'success' && !empty($file_return['file_location'])) {
					$return = $file_return['file_location'];

					$sql = "INSERT INTO resources_files 
							(created, user_id, resources_id, type, file_path, file_name)
							VALUES 
							(:created, :user_id, :resources_id, :type, :file_path, :file_name);";
					$result = $this->db->prepare($sql);
					$pdo_array = array();
					$pdo_array[':created'] = date("Y-m-d H:i:s");
					$pdo_array[':user_id'] = $this->getGlobalUser();
					$pdo_array[':resources_id'] = $resources_id;
					$pdo_array[':type'] = $file_type;
					$pdo_array[':file_path'] = $data['target'];
					$pdo_array[':file_name'] = $_FILES["fileToUpload"]["name"];
					$result->execute($pdo_array);
					$id = $this->db->lastInsertId();

					$logger = new Logger();
					$logger->logPDO("".$this->getGlobalUser(), "resources_files", "add new", $id, $sql, $pdo_array);
				} else {
					return "file create failure";
					//return file create failure
				}
			} else {
				return "invalid file name error - unreadable suffix";
				//return invalid file name error - unreadable suffix
			}
		} else {
			return "invalid file name error - empty name";
			//return invalid file name error - empty name
		}
		echo $return;
	}

	public function getLatestResourceFile($resources_id, $file_type) {
		$sql = "SELECT file_path, file_name FROM resources_files WHERE active = 1 AND resources_id= :resources_id AND type = :type ORDER BY id DESC LIMIT 1";
		$query = $this->db->prepare($sql);
		$pdo_array = array();
		$pdo_array[':resources_id'] = $resources_id;
		$pdo_array[':type'] = $file_type;
		$query->execute($pdo_array);
		$resource = $query->fetch(PDO::FETCH_OBJ);
		if (!empty($resource->file_name)) {
			$resource->full_path = $resource->file_path.$resource->file_name;
		} else {
			$resource = new stdClass();
			$resource->file_path = "";
			$resource->file_name = "";
			$resource->full_path = "";
		}

		return $resource;
	}


}
