<?php
class Resources extends Application
{

	public $db;

	public function __construct()	{
		//fetch db from Application for reference
		$this->db = parent::getDatabase();
	}

	public function getResource($id) {
		$query = $this->db->prepare("SELECT * FROM `resources` WHERE `id`= :id");
		$query->execute(array(':id' => $id));
		$resource = $query->fetch(PDO::FETCH_OBJ);
		return $resource;
	}

	public function getCount() {
		$sql = "SELECT count(*) FROM `resources` WHERE active = 1";
		$result = $this->db->prepare($sql);
		$result->execute();
		$number_of_rows = $result->fetchColumn();
		return $number_of_rows;
	}

	public function delete($id) {
		$sql = "UPDATE `resources` SET active = 0 WHERE id = :id";
		$result = $this->db->prepare($sql);
		$pdo_array[':id']  = $id;
		$result->execute($pdo_array);

		$logger = new Logger();
		$logger->logPDO("".$this->getGlobalUser(), "resources", "delete", $id, $sql, $pdo_array);

		return true;;
	}

	public function getResources($data = array()) {
		$sql = "SELECT *,
		(SELECT GROUP_CONCAT(tags.tag SEPARATOR ';') FROM tags WHERE tags.id IN (SELECT resource_to_tags.tag_id FROM resource_to_tags WHERE resource_to_tags.resource_id = resources.id)) as categories
		FROM `resources` ";
		$sql .= " WHERE id != '' AND active = 1";

		$pdo_variables = array();

		if (!empty($data['filter_id'])) {
			if (!empty(str_replace(" ","",$data['filter_id']))) {
				$explode = explode (" ", $data['filter_id']);
				$sql .= " AND (";
				$count = 0;
				foreach ($explode as $val) {
					if ($count > 0) {
						$sql .= " OR ";
					}
					$sql .= "id = ?";
					$pdo_variables[] = $val;
					$count++;
				}
				$sql .= ")";
			}
		}

		if (!empty($data['filter_tags'])) {
			$sql .= " AND (id IN (SELECT resource_id FROM resource_to_tags WHERE resource_to_tags.tag_id = ?)) ";
				$pdo_variables[] = (int)$data['filter_tags'];
		}

		if (!empty($data['exclude_id'])) {
			if (!empty(str_replace(" ","",$data['exclude_id']))) {
				$explode = explode (" ", $data['exclude_id']);
				foreach ($explode as $val) {
					if (!empty($val)) {
						$sql .= " AND NOT id = ?";
						$pdo_variables[] = $val;
					}
				}
			}
		}

		if (!empty($data['filter_swedish_word'])) {
			if (!empty(str_replace(" ","",$data['filter_swedish_word']))) {
				$explode = explode (" ", $data['filter_swedish_word']);
				$sql .= " AND (";
				$count = 0;
				foreach ($explode as $val) {
					if ($count > 0) {
						$sql .= " OR ";
					}
					$sql .= "swe_word LIKE ?";
					$pdo_variables[] = "%".$val."%";
					$count++;
				}
				$sql .= ")";
			}
		}

		if (!empty($data['filter_elfdalian_word'])) {
			if (!empty(str_replace(" ","",$data['filter_elfdalian_word']))) {
				$explode = explode (" ", $data['filter_elfdalian_word']);
				$sql .= " AND (";
				$count = 0;
				foreach ($explode as $val) {
					if ($count > 0) {
						$sql .= " OR ";
					}
					$sql .= "elfdalian_word LIKE ?";
					$pdo_variables[] = "%".$val."%";
					$count++;
				}
				$sql .= ")";
			}
		}

		if (!empty($data['sort'])) {
			$sql .= " ORDER BY ?";
			$pdo_variables[] = $data['sort'];
		} else {
			$sql .= " ORDER BY id";
		}

		if (isset($data['order']) && ($data['order'] == 'ASC')) {
			$sql .= " ASC, id ASC";
		} else {
			$sql .= " DESC, id DESC";
		}

		if (isset($data['start']) || isset($data['limit'])) {
			if (empty($data['start'])) {
				$data['start'] = 0;
			}
			if (empty($data['limit'])) {
				$data['limit'] = 20;
			}
			$sql .= " LIMIT ".$data['start']." , ".$data['limit']." ";
		}
		
		$query = $this->db->prepare($sql);
		$query->execute($pdo_variables);

		//$logger = new Logger();
		//echo "<p>".$logger->fillSQLsequential($sql, $pdo_variables)."</p>";

		$data = $query->fetchAll(PDO::FETCH_OBJ);
		return $data;
	}

	public function addResource($data = array()) {
    	if(!empty($data)) {
	    	$sql = "INSERT INTO `resources`(";
			$fields = array();

			//list of fields in the table
			$clearing_fields = array(
				'swe_word',
				'elfdalian_word'
			);

			$fields['created'] = date("Y-m-d H:i:s");
			$fields['updated'] = date("Y-m-d H:i:s");
			$fields['created_user_id'] = $this->getGlobalUser();
			$fields['updated_user_id'] = $this->getGlobalUser();

			foreach($clearing_fields as $field) {
				if(isset($data[$field])) {
					if($data[$field] == '') {
						$fields[$field] = NULL;
					} else {
						$fields[$field] = $data[$field];
					}
				}
			}

			//map the fields to the right area of sql query
			foreach($fields as $field_name=>$value) {
				$names[] = $field_name;
				$values[] = $value;
			}

			//build the columns list to update
			$i = 0;
			$len = count($names);
			foreach($names as $name) {
				$sql .= '`'.$name.'`';
				if ($i != $len - 1) {
			        $sql .= ", ";
			    } else {
			    	$sql .= ") VALUES (";
				}
				$i++;
			}

			//build the values list to update
			$i = 0;
			$len = count($values);
			foreach($names as $name) {
				$sql .= ":". $name;
				if ($i != $len - 1) {
			        $sql .= ", ";
			    } else {
			    	$sql .= ")";
				}
				$i++;
			}

			//set up all the pdo prepare statements
			$pdo_array = array();
			foreach($fields as $field_name=>$value) {
				$pdo_array[':'.$field_name] = $value;
			}

			//prepare the query
			$query = $this->db->prepare($sql);

			//execute query with all variables
			$query->execute($pdo_array);

			$id = $this->db->lastInsertId();

			$logger = new Logger();
			$logger->logPDO("".$this->getGlobalUser(), "resources", "add new", $id, $sql, $pdo_array);
		}
		return $id;
	}

	public function updateResource($data = array()) {
    	if(!empty($data)) {
	    	$sql = "UPDATE `resources` SET";
			$fields = array();

			//list of fields in the table
			$table_fields = array(
				'swe_word',
				'elfdalian_word'
			);

			$fields['updated'] = date("Y-m-d H:i:s");
			$fields['updated_user_id'] = $this->getGlobalUser();

			foreach($table_fields as $field) {
				if(isset($data[$field])) {
					if($data[$field] == '') {
						$fields[$field] = NULL;
					} else {
						$fields[$field] = $data[$field];
					}
				}
			}

			//map the fields to the right area of sql query
			foreach($fields as $field_name=>$value) {
				$sql .= ' `' . $field_name . '`=:' . $field_name .',';
			}

			//set up all the pdo prepare statements
			$pdo_array = array();
			foreach($fields as $field_name=>$value) {
				$pdo_array[':'.$field_name] = $value;
			}

			//strip comman from last entry
			$sql = rtrim($sql, ",");

			$sql .= " WHERE `id`= :id";
			$pdo_array[':id'] = $data['id'];

			//prepare the query
			$query = $this->db->prepare($sql);

			//execute query with all variables
			$query->execute($pdo_array);

			$logger = new Logger();
			$logger->logPDO("".$this->getGlobalUser(), "resources", "update", $data['id'], $sql, $pdo_array);
		}
		return;
	}

	public function setTags($id, $tag_array) {
		$sql = "DELETE FROM resource_to_tags WHERE resource_id = :id";
		$result = $this->db->prepare($sql);
		$pdo_array[':id']  = $id;
		$result->execute($pdo_array);

		$logger = new Logger();
		$log_sql = "";
		$log_count = 0;
		$batch_count = 0;

		foreach ($tag_array as $tag) {
			if ($log_count > 50) {
				$batch_count++;
				$logger->log("".$this->getGlobalUser(), "resource_to_tags", "set tags - batch ".$batch_count, $id, $log_sql);
				$log_sql = "";
				$log_count = 0;
			}

			$sql = "INSERT INTO resource_to_tags (resource_id, tag_id) VALUES (:id, :tag_id)";
			$pdo_array[':tag_id'] = $tag;
			$result = $this->db->prepare($sql);
			$result->execute($pdo_array);

			$log_sql .= $logger->fillSQL($sql, $pdo_array)."\n";
			$log_count++;
		}

		$logger->log("".$this->getGlobalUser(), "resource_to_tags", "set tags", $id, $log_sql);
	}

	public function addTag($id, $tag) {
		$logger = new Logger();
		$log_sql = "";
		$log_count = 0;
		$batch_count = 0;

		$sql = "INSERT INTO resource_to_tags (resource_id, tag_id) VALUES (:id, :tag_id)";
		$pdo_array[':tag_id'] = $tag;
		$pdo_array[':id'] = $id;

		$result = $this->db->prepare($sql);
		$result->execute($pdo_array);

		$log_sql .= $logger->fillSQL($sql, $pdo_array)."\n";
		$log_count++;

		$logger->log("".$this->getGlobalUser(), "resource_to_tags", "set tags", $id, $log_sql);
	}

	public function addResourceFile($resources_id, $file, $file_type) {
		$_FILES["fileToUpload"] = $file;
		if (!empty($_FILES["fileToUpload"]["name"])) {
			$existing_count_q = "SELECT count(id) FROM `resources_files` WHERE resources_id = :resources_id AND type = :type";
			$pdo_array[':type'] = $file_type;
			$pdo_array[':resources_id'] = $resources_id;
			$result = $this->db->prepare($existing_count_q);
			$result->execute($pdo_array);
			$number_of_rows = $result->fetchColumn();

			$explode = explode (".", $_FILES["fileToUpload"]["name"]);
			if (count($explode) > 1) {
				$suffix = ".".$explode[count($explode)-1];

				$_FILES["fileToUpload"]["name"] = $resources_id."_".$file_type."_".$number_of_rows.$suffix;
				$data = array();
				$data['target'] = "resourcefiles/".urlencode($file_type)."/";

				$file_return = $this->uploadFile($_FILES, $this->getGlobalUser(), $data);
				$file_success = $file_return['status'];
				if($file_success == 'success' && !empty($file_return['file_location'])) {
					$return = $file_return['file_location'];

					/* Remove any old image or word record before adding the new resource */
					$sql = "DELETE FROM resources_files WHERE resources_id = :resources_id AND type = :type";
					$result = $this->db->prepare($sql);
					$pdo_array = array();
					$pdo_array[':resources_id'] = $resources_id;
					$pdo_array[':type'] = $file_type;
					$result->execute($pdo_array);

					/* Insert the new resource */
					$sql = "INSERT INTO resources_files 
							(created, user_id, resources_id, type, file_path, file_name)
							VALUES 
							(:created, :user_id, :resources_id, :type, :file_path, :file_name);";
					$result = $this->db->prepare($sql);
					$pdo_array = array();
					$pdo_array[':created'] = date("Y-m-d H:i:s");
					$pdo_array[':user_id'] = $this->getGlobalUser();
					$pdo_array[':resources_id'] = $resources_id;
					$pdo_array[':type'] = $file_type;
					$pdo_array[':file_path'] = $data['target'];
					$pdo_array[':file_name'] = $_FILES["fileToUpload"]["name"];
					$result->execute($pdo_array);
					$id = $this->db->lastInsertId();

					$logger = new Logger();
					$logger->logPDO("".$this->getGlobalUser(), "resources_files", "add new", $id, $sql, $pdo_array);
				} else {
					return "file create failure";
					//return file create failure
				}
			} else {
				return "invalid file name error - unreadable suffix";
				//return invalid file name error - unreadable suffix
			}
		} else {
			return "invalid file name error - empty name";
			//return invalid file name error - empty name
		}
		//echo $return;
	}

	public function getLatestResourceFile($resources_id, $file_type) {
		$sql = "SELECT file_path, file_name FROM resources_files WHERE active = 1 AND resources_id= :resources_id AND type = :type ORDER BY id DESC LIMIT 1";
		$query = $this->db->prepare($sql);
		$pdo_array = array();
		$pdo_array[':resources_id'] = $resources_id;
		$pdo_array[':type'] = $file_type;
		$query->execute($pdo_array);
		$resource = $query->fetch(PDO::FETCH_OBJ);
		if (!empty($resource->file_name)) {
			$resource->full_path = $resource->file_path.$resource->file_name;
		} else {
			$resource = new stdClass();
			$resource->file_path = "";
			$resource->file_name = "";
			$resource->full_path = "";
		}

		return $resource;
	}

	public function addTagRow($id) {
		$return = "";

		$sql = "SELECT t.*, tj.resource_count FROM tags t LEFT JOIN (SELECT COUNT(id) as resource_count, tag_id FROM resource_to_tags WHERE tag_id = :id GROUP BY tag_id) tj ON tj.tag_id = t.id WHERE t.id=:id";
		$query = $this->db->prepare($sql);
		$query->execute(array('id'=>$id));
		$tag = $query->fetch();

		if (!empty($tag['id'])) {
			$return  = 	'<tr class="tag_row" id="tag_row_'.$tag['id'].'" tags_id="'.$tag['id'].'">';
			$return .= 		'<input type="hidden" name="tags[]" value="'.$tag['id'].'">';
			$return .= 		'<td>'.$tag['id'].'</td>';
			$return .= 		'<td>'.$tag['tag'].'</td>';
			$return .= 		'<td>'.$tag['resource_count'].'</td>';
			$return .= 		'<td><a href="#" onclick="removeTagRow('.$tag['id'].');return false;"><i class="fas fa-times"></i></a>';
			$return .= 	'</tr>';
		}

		return $return;
	}

	public function fillTagRows($resources_id) {
		$query = $this->db->prepare("SELECT * FROM `resource_to_tags` WHERE resource_id = :resource_id");
		$pdo_array = array();
		$pdo_array[':resource_id'] = $resources_id;
		$query->execute($pdo_array);
		$data = $query->fetchAll(PDO::FETCH_OBJ);

		//$logger = new Logger();
		//echo "<p>".$logger->fillSQLsequential("SELECT * FROM `resource_to_tags` WHERE resource_id = :resource_id", $pdo_array)."</p>";

		$return = "";

		foreach ($data as $tag) {
			$return .= $this->addTagRow($tag->tag_id);
		}

		return $return;
	}

	public function filterTagSelect($filter_name, $exclude_id) {
		$return = "";

		$sql = "SELECT t.*, tj.resource_count FROM tags t LEFT JOIN (SELECT COUNT(id) as resource_count, tag_id FROM resource_to_tags GROUP BY tag_id) tj ON tj.tag_id = t.id ";
		$sql .= "WHERE t.id IS NOT NULL AND t.active = 1 ";

		$pdo_variables = array();

		if (!empty($exclude_id)) {
			if (!empty(str_replace(" ","", $exclude_id))) {
				$explode = explode (" ", $exclude_id);
				foreach ($explode as $val) {
					if (!empty($val)) {
						$sql .= " AND NOT t.id = ?";
						$pdo_variables[] = $val;
					}
				}
			}
		}

		if (!empty($filter_name)) {
			if (!empty(str_replace(" ","", $filter_name))) {
				$explode = explode (" ", $filter_name);
				$sql .= " AND (";
				$count = 0;
				foreach ($explode as $val) {
					if ($count > 0) {
						$sql .= " OR ";
					}
					$sql .= "t.tag LIKE ?";
					$pdo_variables[] = "%".$val."%";
					$count++;
				}
				$sql .= ")";
			}
		}

		$sql .= "ORDER BY resource_count DESC, tag ASC LIMIT 20";

		//$logger = new Logger();
		//echo "<p>".$logger->fillSQLsequential($sql, $pdo_variables)."</p>";

		$query = $this->db->prepare($sql);
		$query->execute($pdo_variables);
		$data = $query->fetchAll(PDO::FETCH_OBJ);

		$return .= '<select id="searchTag" name="searchTag">';
		$return .= '<option value="" selected></option>';
		foreach($data as $tag) {
			if (empty($tag->resource_count)) {$tag->resource_count = 0;}
			$return .= '<option value="'.$tag->id.'">'.$tag->id.': '.$tag->tag.' ('.$tag->resource_count.')</option>';
		}
		$return .= '</select>';

		return $return;
	}



}
